# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add submitted and complete notification templates


Revision ID: cb49c557f7e8
Revises: 32a78fe3bb5e
Create Date: 2021-04-08 12:29:10.757973

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "cb49c557f7e8"
down_revision = "32a78fe3bb5e"
branch_labels = None
depends_on = None


def upgrade():
    op.execute(
        """
    INSERT INTO notification_templates (name, description, template)
    VALUES ('submitted_email',
     'An email template for notifying a user that their capability request has been submitted.',
     'Subject: NRAO Workspaces Request #{{request_id}}: Submitted\n\n
      Dear User,\n
      Your {{capability_name}} request has been submitted.\n
      You will be notified when it is complete.\n
      The status of your request can be tracked here:\n
      {{{status_link}}}\n
      Best regards,\n
      NRAO Workspaces
      ')
    """
    )

    op.execute(
        """
    INSERT INTO notification_templates (name, description, template)
    VALUES ('complete_email',
    'An email template for notifying a user that their capability request is now complete.',
    'Subject: NRAO Workspaces Request #{{request_id}}: Complete\n\n
    Dear User,\n
    Thank you for using NRAO Workspaces.\n
    Your {{capbility_name}} request is now complete.\n
    Best regards,
    NRAO Workspaces')
    """
    )


def downgrade():
    op.execute(
        """
    DELETE FROM notification_templates WHERE name = 'submitted_email'
    """
    )

    op.execute(
        """
    DELETE FROM notification_templates WHERE name = 'complete_email'
    """
    )
